# Python-RoseDB-Driver
A simple, unsophisticated Python Driver for [RoseDB](https://github.com/ShindouMihou/RoseDB). Currently supports deleting, adding values to filtering and aggregation of database and collections.

## Set-Up

Setting up the connection is fairly simple.
```Python
RoseDriver = Rosebuilder.RoseDriver("127.0.0.1", 5995, "autherization")
```
